var struct__h__connection =
[
    [ "connection", "struct__h__connection.html#a9ed88f0f51c3c38cccee9b9d87b2697a", null ],
    [ "type", "struct__h__connection.html#a5f73066044ef8afe4d8e8c2be5a8b8bb", null ]
];