var hoel_8c =
[
    [ "h_clean_connection", "group__init.html#ga2b25bbc6f6ad1b2cdc6fbfa699107f02", null ],
    [ "h_clean_data", "group__h__result.html#ga7354340a71530db5871477ca9983d942", null ],
    [ "h_clean_data_full", "group__h__result.html#ga495bbb790c212dbf1ed86e2248068f29", null ],
    [ "h_clean_result", "group__h__result.html#ga73e1db71f8116899d8f0d3fbdef52fe9", null ],
    [ "h_close_db", "group__init.html#gab40470ec35a8b69aab63d0938fd2c5d0", null ],
    [ "h_escape_string", "group__escape.html#gacc218bee033b7fdbcd4bf103531d2afa", null ],
    [ "h_escape_string_with_quotes", "group__escape.html#ga384df23c2bef007254a2bf8fd0933874", null ],
    [ "h_execute_query", "group__h__result.html#gac4da4e6a96c38e2022718b0e9f5a411d", null ],
    [ "h_execute_query_json", "group__json.html#gabe251e9c7f7e4b80506e57823f87c134", null ],
    [ "h_free", "group__memory.html#ga8e836d6e4152a26211a31f94b819ce56", null ],
    [ "h_new_data_blob", "hoel_8c.html#a62c32cdb8eae65b99a9331d3b5d34991", null ],
    [ "h_new_data_datetime", "hoel_8c.html#a09329ba6d5ce119d0b1af39bc12f7368", null ],
    [ "h_new_data_double", "hoel_8c.html#a62a2e192ad912739cecf09c229415178", null ],
    [ "h_new_data_int", "hoel_8c.html#a54adaf78809646c421a548671efa2312", null ],
    [ "h_new_data_null", "hoel_8c.html#a17b4e67ef3f9516ef7b4acf761151f21", null ],
    [ "h_new_data_text", "hoel_8c.html#ae533da5edc77fc582c3a12124b9107ca", null ],
    [ "h_query_delete", "group__h__result.html#gad5fd3abd6fa8b69e66c2b8a0be0c8c31", null ],
    [ "h_query_insert", "group__h__result.html#ga2059c4addcd2b5e9d21948e84b04e6e3", null ],
    [ "h_query_last_insert_id", "group__h__result.html#ga2301917e82d730873a683e4de34a9137", null ],
    [ "h_query_select", "group__h__result.html#ga6a32dbb87ff1e44d3714a2db7cc61024", null ],
    [ "h_query_select_json", "group__json.html#gafd14a9c6a0d0adb4168f3eab90b73999", null ],
    [ "h_query_update", "group__h__result.html#ga26b26b857754b240163242e8a69e6ee1", null ],
    [ "h_result_add_row", "hoel_8c.html#af4b4ebdda46e4feebdb27748428738fd", null ],
    [ "h_row_add_data", "hoel_8c.html#adb6c601ac4cd8346568f6c3c1a0a3c8b", null ]
];