var group__struct =
[
    [ "_h_connection", "struct__h__connection.html", [
      [ "connection", "struct__h__connection.html#a9ed88f0f51c3c38cccee9b9d87b2697a", null ],
      [ "type", "struct__h__connection.html#a5f73066044ef8afe4d8e8c2be5a8b8bb", null ]
    ] ],
    [ "_h_type_int", "struct__h__type__int.html", [
      [ "value", "struct__h__type__int.html#a63b159bcf76ed3ee7c801e7acaf3665f", null ]
    ] ],
    [ "_h_type_double", "struct__h__type__double.html", [
      [ "value", "struct__h__type__double.html#ad9d041d6bec810afb457c94879bf8577", null ]
    ] ],
    [ "_h_type_datetime", "struct__h__type__datetime.html", [
      [ "value", "struct__h__type__datetime.html#af555d83eb9314c26fb97487edb3ea778", null ]
    ] ],
    [ "_h_type_text", "struct__h__type__text.html", [
      [ "length", "struct__h__type__text.html#a1c8c95b35e9ffe1ceecf4368e1cbf1dc", null ],
      [ "value", "struct__h__type__text.html#aba822203767cd4c172d99e00a3a1f0d2", null ]
    ] ],
    [ "_h_type_blob", "struct__h__type__blob.html", [
      [ "length", "struct__h__type__blob.html#ad6a81fa5351918d2b1d0367ac706e4a7", null ],
      [ "value", "struct__h__type__blob.html#ae3950b9a6d86c25d0f590d2ab85de203", null ]
    ] ],
    [ "_h_data", "struct__h__data.html", [
      [ "t_data", "struct__h__data.html#aa4e6327290e2182af0d518e6ac62d0cc", null ],
      [ "type", "struct__h__data.html#a012cea152bfec077b2797193236a86fa", null ]
    ] ],
    [ "_h_result", "struct__h__result.html", [
      [ "data", "struct__h__result.html#a5a94257899ef17092f6d56f6e942da6a", null ],
      [ "nb_columns", "struct__h__result.html#a89005cca8583b65926b0b6493e115f4c", null ],
      [ "nb_rows", "struct__h__result.html#a1f54b961d31584ab692e67d629c1e350", null ]
    ] ]
];