var group__const =
[
    [ "H_ERROR", "group__const.html#ga3d13dec292e13d7084bd02bf88644bc7", null ],
    [ "H_ERROR_CONNECTION", "group__const.html#ga0beccf85ad5055383c16f116dbf09758", null ],
    [ "H_ERROR_MEMORY", "group__const.html#gad4789295ad35dfe7099b19df323fc251", null ],
    [ "H_ERROR_PARAMS", "group__const.html#ga89efbf0495effc8dd486af9fb432653a", null ],
    [ "H_ERROR_QUERY", "group__const.html#gadc4aeed3b04514c46523d84b8e872a21", null ],
    [ "H_OK", "group__const.html#ga2b0e9e34c11ac9292866c6771af2b12e", null ],
    [ "H_OPTION_EXEC", "group__const.html#gae174b45ba80d047854be06d7f8593525", null ],
    [ "H_OPTION_NONE", "group__const.html#ga21692e73b559e3d952f92b35927bc92e", null ],
    [ "H_OPTION_SELECT", "group__const.html#ga22e4dd967a326fc6a2759f147a7d58a7", null ],
    [ "HOEL_COL_TYPE_BLOB", "group__const.html#ga6b39fe8450b8dd07b738de50d64cab8b", null ],
    [ "HOEL_COL_TYPE_BOOL", "group__const.html#ga2c5246e47056b3cb2faef9a0c465ac3c", null ],
    [ "HOEL_COL_TYPE_DATE", "group__const.html#gaf32a427dbadaed22068277a86979211f", null ],
    [ "HOEL_COL_TYPE_DOUBLE", "group__const.html#ga128b345a4dab00a87aac21948e40a673", null ],
    [ "HOEL_COL_TYPE_INT", "group__const.html#ga94a6519c7458e1f763b064b6bb2746cb", null ],
    [ "HOEL_COL_TYPE_NULL", "group__const.html#ga34f2e0605fd8a209e39bcf48f50dfd7f", null ],
    [ "HOEL_COL_TYPE_TEXT", "group__const.html#gad03d4e2ddf1af58f9312521e85ded9cd", null ],
    [ "HOEL_DB_TYPE_MARIADB", "group__const.html#ga16b3a4b240b8e29b1530fb9da9881cb1", null ],
    [ "HOEL_DB_TYPE_PGSQL", "group__const.html#ga68d2ce9cb6d393200d5a1fa38c30ba59", null ],
    [ "HOEL_DB_TYPE_SQLITE", "group__const.html#gaa04699d4718683a7ae0cad920ac40ca9", null ]
];