var struct__h__type__text =
[
    [ "length", "struct__h__type__text.html#a1c8c95b35e9ffe1ceecf4368e1cbf1dc", null ],
    [ "value", "struct__h__type__text.html#aba822203767cd4c172d99e00a3a1f0d2", null ]
];