var group__init =
[
    [ "h_clean_connection", "group__init.html#ga2b25bbc6f6ad1b2cdc6fbfa699107f02", null ],
    [ "h_close_db", "group__init.html#gab40470ec35a8b69aab63d0938fd2c5d0", null ],
    [ "h_close_mariadb", "group__init.html#ga2a887ec4ccb635d17a663722a23c02b6", null ],
    [ "h_close_pgsql", "group__init.html#gaf01bb27a15bd380469271a1f673ea7c6", null ],
    [ "h_close_sqlite", "group__init.html#gaaecdea780d8e2f12c98ad686d07400c0", null ],
    [ "h_connect_mariadb", "group__init.html#ga9d2297ed031b835f9130d75c1122ad5b", null ],
    [ "h_connect_pgsql", "group__init.html#ga0ffe1995e20fd007e588cb4ea684e5ac", null ],
    [ "h_connect_sqlite", "group__init.html#ga6143b7f858b45d6a39d53fd60ea39214", null ]
];