var searchData=
[
  ['queries_0',['Simple JSON queries',['../index.html#autotoc_md31',1,'']]],
  ['query_1',['Execute a SQL query',['../index.html#autotoc_md26',1,'']]],
  ['query_20functions_2',['Additional query functions',['../index.html#autotoc_md30',1,'']]]
];
