var annotated_dup =
[
    [ "_h_connection", "struct__h__connection.html", "struct__h__connection" ],
    [ "_h_data", "struct__h__data.html", "struct__h__data" ],
    [ "_h_result", "struct__h__result.html", "struct__h__result" ],
    [ "_h_type_blob", "struct__h__type__blob.html", "struct__h__type__blob" ],
    [ "_h_type_datetime", "struct__h__type__datetime.html", "struct__h__type__datetime" ],
    [ "_h_type_double", "struct__h__type__double.html", "struct__h__type__double" ],
    [ "_h_type_int", "struct__h__type__int.html", "struct__h__type__int" ],
    [ "_h_type_text", "struct__h__type__text.html", "struct__h__type__text" ]
];