var struct__h__type__blob =
[
    [ "length", "struct__h__type__blob.html#ad6a81fa5351918d2b1d0367ac706e4a7", null ],
    [ "value", "struct__h__type__blob.html#ae3950b9a6d86c25d0f590d2ab85de203", null ]
];