var hoel_8h =
[
    [ "__USE_XOPEN", "hoel_8h.html#a8773045a81f883f2ab00761f45e8642c", null ],
    [ "H_ERROR", "group__const.html#ga3d13dec292e13d7084bd02bf88644bc7", null ],
    [ "H_ERROR_CONNECTION", "group__const.html#ga0beccf85ad5055383c16f116dbf09758", null ],
    [ "H_ERROR_MEMORY", "group__const.html#gad4789295ad35dfe7099b19df323fc251", null ],
    [ "H_ERROR_PARAMS", "group__const.html#ga89efbf0495effc8dd486af9fb432653a", null ],
    [ "H_ERROR_QUERY", "group__const.html#gadc4aeed3b04514c46523d84b8e872a21", null ],
    [ "H_OK", "group__const.html#ga2b0e9e34c11ac9292866c6771af2b12e", null ],
    [ "H_OPTION_EXEC", "group__const.html#gae174b45ba80d047854be06d7f8593525", null ],
    [ "H_OPTION_NONE", "group__const.html#ga21692e73b559e3d952f92b35927bc92e", null ],
    [ "H_OPTION_SELECT", "group__const.html#ga22e4dd967a326fc6a2759f147a7d58a7", null ],
    [ "HOEL_COL_TYPE_BLOB", "group__const.html#ga6b39fe8450b8dd07b738de50d64cab8b", null ],
    [ "HOEL_COL_TYPE_BOOL", "group__const.html#ga2c5246e47056b3cb2faef9a0c465ac3c", null ],
    [ "HOEL_COL_TYPE_DATE", "group__const.html#gaf32a427dbadaed22068277a86979211f", null ],
    [ "HOEL_COL_TYPE_DOUBLE", "group__const.html#ga128b345a4dab00a87aac21948e40a673", null ],
    [ "HOEL_COL_TYPE_INT", "group__const.html#ga94a6519c7458e1f763b064b6bb2746cb", null ],
    [ "HOEL_COL_TYPE_NULL", "group__const.html#ga34f2e0605fd8a209e39bcf48f50dfd7f", null ],
    [ "HOEL_COL_TYPE_TEXT", "group__const.html#gad03d4e2ddf1af58f9312521e85ded9cd", null ],
    [ "HOEL_DB_TYPE_MARIADB", "group__const.html#ga16b3a4b240b8e29b1530fb9da9881cb1", null ],
    [ "HOEL_DB_TYPE_PGSQL", "group__const.html#ga68d2ce9cb6d393200d5a1fa38c30ba59", null ],
    [ "HOEL_DB_TYPE_SQLITE", "group__const.html#gaa04699d4718683a7ae0cad920ac40ca9", null ],
    [ "h_build_where_clause", "group__json.html#gab9fa863445de66a749903c171e3c3479", null ],
    [ "h_clean_connection", "group__init.html#ga2b25bbc6f6ad1b2cdc6fbfa699107f02", null ],
    [ "h_clean_data", "group__h__result.html#ga7354340a71530db5871477ca9983d942", null ],
    [ "h_clean_data_full", "group__h__result.html#ga495bbb790c212dbf1ed86e2248068f29", null ],
    [ "h_clean_result", "group__h__result.html#ga73e1db71f8116899d8f0d3fbdef52fe9", null ],
    [ "h_close_db", "group__init.html#gab40470ec35a8b69aab63d0938fd2c5d0", null ],
    [ "h_close_mariadb", "group__init.html#ga2a887ec4ccb635d17a663722a23c02b6", null ],
    [ "h_close_pgsql", "group__init.html#gaf01bb27a15bd380469271a1f673ea7c6", null ],
    [ "h_close_sqlite", "group__init.html#gaaecdea780d8e2f12c98ad686d07400c0", null ],
    [ "h_connect_mariadb", "group__init.html#ga9d2297ed031b835f9130d75c1122ad5b", null ],
    [ "h_connect_pgsql", "group__init.html#ga0ffe1995e20fd007e588cb4ea684e5ac", null ],
    [ "h_connect_sqlite", "group__init.html#ga6143b7f858b45d6a39d53fd60ea39214", null ],
    [ "h_delete", "group__json.html#ga843285b39babfdb6e4f49be4a85588b6", null ],
    [ "h_escape_string", "group__escape.html#gacc218bee033b7fdbcd4bf103531d2afa", null ],
    [ "h_escape_string_mariadb", "group__escape.html#gad802ef45c74fb57996a115510c3d94ef", null ],
    [ "h_escape_string_pgsql", "group__escape.html#ga32b3a3782cab1b47af529670d078e25e", null ],
    [ "h_escape_string_sqlite", "group__escape.html#gaa65d8f7de3b61471bcda315227bb276e", null ],
    [ "h_escape_string_with_quotes", "group__escape.html#ga384df23c2bef007254a2bf8fd0933874", null ],
    [ "h_escape_string_with_quotes_mariadb", "group__escape.html#gab89b39ff2665698547950abfa76003c7", null ],
    [ "h_escape_string_with_quotes_pgsql", "group__escape.html#ga1a8a2a4c53888630012dfb181d98b35a", null ],
    [ "h_escape_string_with_quotes_sqlite", "group__escape.html#ga08f363c5874acf5e1f660d798979c6b6", null ],
    [ "h_exec_query_sqlite", "group__json.html#gaab245ab97e8391a77bf72925314fde7c", null ],
    [ "h_execute_query", "group__h__result.html#gac4da4e6a96c38e2022718b0e9f5a411d", null ],
    [ "h_execute_query_json", "group__json.html#gabe251e9c7f7e4b80506e57823f87c134", null ],
    [ "h_execute_query_json_mariadb", "group__json.html#ga3e98c1f7cd5735cd022b9152214a1a55", null ],
    [ "h_execute_query_json_pgsql", "group__json.html#ga5da953adea4001d844997fe33c60dba0", null ],
    [ "h_execute_query_json_sqlite", "group__json.html#gad2309996c20a68003bc325175c8d70ee", null ],
    [ "h_execute_query_mariadb", "group__h__result.html#gafd9f4d579c98568701887907d5aa6c04", null ],
    [ "h_execute_query_pgsql", "group__h__result.html#gac1f25365ea82d3540fb3c0e97330168d", null ],
    [ "h_execute_query_sqlite", "group__json.html#ga7a0f0e0215dd97019e525c023c612ca1", null ],
    [ "h_free", "group__memory.html#ga8e836d6e4152a26211a31f94b819ce56", null ],
    [ "h_get_mariadb_value", "group__h__result.html#ga9e8e348e1e5a9de74eb36848af7ff1f7", null ],
    [ "h_insert", "group__json.html#gac54383a1213ccf6c74baa1fd82f9ae44", null ],
    [ "h_last_insert_id", "group__json.html#ga8f6e2abf97c30792018f108b87d5ef0e", null ],
    [ "h_last_insert_id_mariadb", "group__json.html#gabb47bc5e480c156459088223f09a4869", null ],
    [ "h_last_insert_id_pgsql", "group__json.html#ga8b372a28b6ea02e4e6bf3e553fb2d012", null ],
    [ "h_last_insert_id_sqlite", "group__json.html#ga64ff10ca207c60a5b3dca185983c0e40", null ],
    [ "h_query_delete", "group__h__result.html#gad5fd3abd6fa8b69e66c2b8a0be0c8c31", null ],
    [ "h_query_insert", "group__h__result.html#ga2059c4addcd2b5e9d21948e84b04e6e3", null ],
    [ "h_query_last_insert_id", "group__h__result.html#ga2301917e82d730873a683e4de34a9137", null ],
    [ "h_query_select", "group__h__result.html#ga6a32dbb87ff1e44d3714a2db7cc61024", null ],
    [ "h_query_select_json", "group__json.html#gafd14a9c6a0d0adb4168f3eab90b73999", null ],
    [ "h_query_update", "group__h__result.html#ga26b26b857754b240163242e8a69e6ee1", null ],
    [ "h_select", "group__json.html#gaa8e35275d04ef39c7e08262b094c43e3", null ],
    [ "h_select_query_sqlite", "group__h__result.html#gae2423e6336326217d6fb182d009ddfb3", null ],
    [ "h_update", "group__json.html#gae94519fb1c32a405530cb43e244b71ee", null ]
];