var topics =
[
    [ "Constants", "group__const.html", "group__const" ],
    [ "struct _h_data", "group__struct.html", "group__struct" ],
    [ "Initialize and cosing connection functions", "group__init.html", "group__init" ],
    [ "Memory management functions", "group__memory.html", "group__memory" ],
    [ "Escape string functions", "group__escape.html", "group__escape" ],
    [ "_h_result SQL query management functions", "group__h__result.html", "group__h__result" ],
    [ "JSON SQL query management functions", "group__json.html", "group__json" ]
];