var struct__h__result =
[
    [ "data", "struct__h__result.html#a5a94257899ef17092f6d56f6e942da6a", null ],
    [ "nb_columns", "struct__h__result.html#a89005cca8583b65926b0b6493e115f4c", null ],
    [ "nb_rows", "struct__h__result.html#a1f54b961d31584ab692e67d629c1e350", null ]
];