var group__h__result =
[
    [ "h_clean_data", "group__h__result.html#ga7354340a71530db5871477ca9983d942", null ],
    [ "h_clean_data_full", "group__h__result.html#ga495bbb790c212dbf1ed86e2248068f29", null ],
    [ "h_clean_result", "group__h__result.html#ga73e1db71f8116899d8f0d3fbdef52fe9", null ],
    [ "h_execute_query", "group__h__result.html#gac4da4e6a96c38e2022718b0e9f5a411d", null ],
    [ "h_execute_query_mariadb", "group__h__result.html#gafd9f4d579c98568701887907d5aa6c04", null ],
    [ "h_execute_query_pgsql", "group__h__result.html#gac1f25365ea82d3540fb3c0e97330168d", null ],
    [ "h_get_mariadb_value", "group__h__result.html#ga9e8e348e1e5a9de74eb36848af7ff1f7", null ],
    [ "h_query_delete", "group__h__result.html#gad5fd3abd6fa8b69e66c2b8a0be0c8c31", null ],
    [ "h_query_insert", "group__h__result.html#ga2059c4addcd2b5e9d21948e84b04e6e3", null ],
    [ "h_query_last_insert_id", "group__h__result.html#ga2301917e82d730873a683e4de34a9137", null ],
    [ "h_query_select", "group__h__result.html#ga6a32dbb87ff1e44d3714a2db7cc61024", null ],
    [ "h_query_update", "group__h__result.html#ga26b26b857754b240163242e8a69e6ee1", null ],
    [ "h_select_query_sqlite", "group__h__result.html#gae2423e6336326217d6fb182d009ddfb3", null ]
];