var searchData=
[
  ['last_20id_20inserted_0',['Get last id inserted',['../index.html#autotoc_md29',1,'']]],
  ['last_20insert_20id_1',['JSON last insert id',['../index.html#autotoc_md33',1,'']]],
  ['libraries_2',['Database libraries',['../index.html#autotoc_md5',1,'']]],
  ['library_3',['Yder (simple logs library)',['../index.html#autotoc_md12',1,'']]],
  ['logs_20library_4',['Yder (simple logs library)',['../index.html#autotoc_md12',1,'']]]
];
