var group__json =
[
    [ "h_build_where_clause", "group__json.html#gab9fa863445de66a749903c171e3c3479", null ],
    [ "h_delete", "group__json.html#ga843285b39babfdb6e4f49be4a85588b6", null ],
    [ "h_exec_query_sqlite", "group__json.html#gaab245ab97e8391a77bf72925314fde7c", null ],
    [ "h_execute_query_json", "group__json.html#gabe251e9c7f7e4b80506e57823f87c134", null ],
    [ "h_execute_query_json_mariadb", "group__json.html#ga3e98c1f7cd5735cd022b9152214a1a55", null ],
    [ "h_execute_query_json_pgsql", "group__json.html#ga5da953adea4001d844997fe33c60dba0", null ],
    [ "h_execute_query_json_sqlite", "group__json.html#gad2309996c20a68003bc325175c8d70ee", null ],
    [ "h_execute_query_sqlite", "group__json.html#ga7a0f0e0215dd97019e525c023c612ca1", null ],
    [ "h_insert", "group__json.html#gac54383a1213ccf6c74baa1fd82f9ae44", null ],
    [ "h_last_insert_id", "group__json.html#ga8f6e2abf97c30792018f108b87d5ef0e", null ],
    [ "h_last_insert_id_mariadb", "group__json.html#gabb47bc5e480c156459088223f09a4869", null ],
    [ "h_last_insert_id_pgsql", "group__json.html#ga8b372a28b6ea02e4e6bf3e553fb2d012", null ],
    [ "h_last_insert_id_sqlite", "group__json.html#ga64ff10ca207c60a5b3dca185983c0e40", null ],
    [ "h_query_select_json", "group__json.html#gafd14a9c6a0d0adb4168f3eab90b73999", null ],
    [ "h_select", "group__json.html#gaa8e35275d04ef39c7e08262b094c43e3", null ],
    [ "h_update", "group__json.html#gae94519fb1c32a405530cb43e244b71ee", null ]
];